SymHashMap

Struct SymHashMap 

pub struct SymHashMap<T>(pub FxHashMap<SymStr, T>);
A convenience abstraction over a String-keyed HashMap

typically used for HashMap<String,Stored> states. The goal is to support both a string interface, as well as the interned tickets interface, while avoiding String allocations internally.

Tuple Fields

0: FxHashMap<SymStr, T>

Implementations

Source

impl<T> SymHashMap<T>

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn get(&self, key: &str) -> Option<&T>

pub fn get_sym(&self, key: SymStr) -> Option<&T>

pub fn get_mut(&mut self, key: &str) -> Option<&mut T>

pub fn get_mut_sym(&mut self, key: SymStr) -> Option<&mut T>

pub fn contains_key(&self, key: &str) -> bool

pub fn contains_key_sym(&self, key: &SymStr) -> bool

pub fn insert(&mut self, key: &str, value: T)

pub fn insert_sym(&mut self, key: SymStr, value: T)

pub fn remove(&mut self, key: &str)

pub fn remove_sym(&mut self, key: SymStr)

pub fn keys(&self) -> Keys<'_, SymStr, T>

pub fn entry(&mut self, key: &str) -> Entry<'_, SymStr, T>

pub fn entry_sym(&mut self, key: SymStr) -> Entry<'_, SymStr, T>

pub fn iter(&self) -> Iter<'_, SymStr, T>